@@ -213,6 +213,10 @@ int32_t SPVM__Net__SSLeay__X509__pubkey_digest(SPVM_ENV* env, SPVM_VALUE* stack)
     return env->die(env, stack, "The length of output buffer $md must be greater than or equal to EVP_MAX_MD_SIZE.", __func__, FILE_NAME, __LINE__);
   }
   
+  if (!len_ref) {
+    return env->die(env, stack, "The reference of the length $len_ref must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
   char* md = (char*)env->get_chars(env, stack, obj_md);
   
   unsigned int len_tmp = 0;
@@ -397,6 +401,10 @@ int32_t SPVM__Net__SSLeay__X509__digest(SPVM_ENV* env, SPVM_VALUE* stack) {
     return env->die(env, stack, "The length of output buffer $md must be greater than or equal to EVP_MAX_MD_SIZE.", __func__, FILE_NAME, __LINE__);
   }
   
+  if (!len_ref) {
+    return env->die(env, stack, "The reference of the length $len_ref must be defined.", __func__, FILE_NAME, __LINE__);
+  }
+  
   char* md = (char*)env->get_chars(env, stack, obj_md);
   
   unsigned int len_tmp = 0;
